
.. py:currentmodule:: pythreejs

BaseBufferGeometry
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: BaseBufferGeometry()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/core/BaseBufferGeometry


    .. py:attribute:: name

        .. sourcecode:: python

            Unicode('', allow_none=False).tag(sync=True)

    .. py:attribute:: type

        .. sourcecode:: python

            Unicode('', allow_none=False).tag(sync=True)

